python-project-structure 0.8.4b1 (2023-04-10)
=============================================

Bugfixes
--------

- Upgrade all requirements to the latest versions as of Mon Apr 10 06:25:02 PM UTC 2023. (upgrade-requirements)


python-project-structure 0.8.4b0 (2023-04-09)
=============================================

Bugfixes
--------

- Upgrade all requirements to the latest versions as of Sun Apr  9 11:19:15 PM UTC 2023. (upgrade-requirements)


python-project-structure 0.1.0b13 (2023-04-06)
==============================================

Bugfixes
--------

- Upgrade all requirements to the latest versions as of Thu Apr  6 11:58:09 AM UTC 2023. (upgrade-requirements)


python-project-structure 0.1.0b12 (2023-04-05)
==============================================

No significant changes.


python-project-structure 0.1.0b11 (2023-04-03)
==============================================

No significant changes.


python-project-structure 0.1.0b10 (2023-04-01)
==============================================

Bugfixes
--------

- Simulate a patch release. (simulate)


python-project-structure 0.1.0b9 (2023-04-01)
=============================================

Bugfixes
--------

- Simulate a patch release. (simulate)


python-project-structure 0.1.0b8 (2023-04-01)
=============================================

Bugfixes
--------

- Upgrade all requirements to the latest versions as of Wed Mar 29 09:48:41 PM UTC 2023. (upgrade-requirements)


python-project-structure 0.1.0b7 (2023-03-24)
=============================================

Bugfixes
--------

- Simulate a patch release. (simulate)


python-project-structure 0.1.0b6 (2023-03-24)
=============================================

Bugfixes
--------

- Upgrade all requirements to the latest versions as of Fri Mar 24 04:25:05 PM UTC 2023. (upgrade-requirements)


Pythonprojectstructure 0.1.0b5 (2023-03-24)
===========================================

Bugfixes
--------

- Simulate a patch release. (simulate)


Pythonprojectstructure 0.1.0b4 (2023-03-24)
===========================================

Bugfixes
--------

- Simulate a patch release. (simulate)


Pythonprojectstructure 0.1.0b3 (2023-03-24)
===========================================

Bugfixes
--------

- Upgrade all requirements to the latest versions as of Fri Mar 24 08:10:28 AM UTC 2023. (upgrade-requirements)


Pythonprojectstructure 0.1.0b2 (2023-03-24)
===========================================

Bugfixes
--------

- Simulate a patch release. (simulate)
- Upgrade all requirements to the latest versions as of Fri Mar 24 03:43:37 AM UTC 2023. (upgrade-requirements)


Pythonprojectstructure 0.1.0b1 (2023-03-21)
===========================================

Bugfixes
--------

- Upgrade all requirements and dependencies to the latest versions. (upgrade-requirements)


Pythonprojectstructure 0.1.0b0 (2023-03-18)
===========================================

No significant changes.
